const tagFilterRules = {
    title: { rule: 'escape' },
    head: { rule: 'escape' },
    body: { rule: 'escape' },
    img: {
        rule: 'filterAttributes',
        disabledAttributes: ['onerror'],
    },
};
export const HtmlFilterPlugin = md => {
    const defaultHtmlBlock = md.renderer.rules.html_block;
    md.renderer.rules.html_block = (tokens, idx, options, env, self) => {
        const token = tokens[idx];
        if (token.type === 'html_block' && !token.tag) {
            let { content } = token;
            for (let tagName in tagFilterRules) {
                const rule = tagFilterRules[tagName];
                const { rule: handleStrategy, disabledAttributes } = rule;
                if (handleStrategy === 'escape') {
                    const start = `<${tagName}>`;
                    const end = `</${tagName}>`;
                    const matchStart = content.replace(new RegExp('\n', 'g'), '').startsWith(start);
                    const matchEnd = content.replace(new RegExp('\n', 'g'), '').endsWith(end);
                    if (matchStart || matchEnd) {
                        content = md.utils.escapeHtml(content);
                        break;
                    }
                }
                else if (handleStrategy === 'filterAttributes' &&
                    disabledAttributes != null &&
                    disabledAttributes.length > 0) {
                    for (let attribute of disabledAttributes) {
                        content = content.replace(new RegExp(`(<${tagName}.*? +)(${attribute}=)(.*?>)`, 'ig'), (match, p1, p2, p3) => p1 + 'data-' + p2 + p3);
                    }
                }
            }
            if (content !== token.content)
                return content;
        }
        return defaultHtmlBlock(tokens, idx, options, env, self);
    };
};
//# sourceMappingURL=html-filter.plugin.js.map