/// <reference types="katex" />
/// <reference types="mathjax2" />

import { MathJaxConfig as MathJaxConfig_2 } from 'mathjax-full/js/components/startup';
import { MathJaxObject as MathJaxObject_2 } from 'mathjax-full/js/components/startup';
import { RenderMathInElementOptions } from 'katex/dist/contrib/auto-render';

export declare const createMathRenderer: <T extends Partial<MathJax2RendererConfig | MathJax3RendererConfig | KatexRendererConfig>>(rendererConfig: T) => IMathRenderer<MathEngine.MathJax2> | IMathRenderer<MathEngine.MathJax3> | IMathRenderer<MathEngine.Katex>;

export declare interface IMathRenderer<TEngine extends MathEngine> {
    config(value: Partial<RendererConfig<TEngine>>): this;
    render(container: HTMLElement, callback?: () => unknown): Promise<void>;
}

declare type KatexRendererConfig = RendererConfig<MathEngine.Katex> & {
    engine: MathEngine.Katex;
};

export declare enum MathEngine {
    MathJax2 = 0,
    MathJax3 = 1,
    Katex = 2
}

export declare type MathJax2RendererConfig = RendererConfig<MathEngine.MathJax2> & {
    engine: MathEngine.MathJax2;
};

export declare type MathJax3RendererConfig = RendererConfig<MathEngine.MathJax3> & {
    engine: MathEngine.MathJax3;
};

declare type MathJaxConfig = MathJaxConfig_2 & {
    tex: Record<string, unknown>;
    [name: string]: unknown;
};

declare interface MathJaxObject {
    config: MathJaxConfig;
    startup: MathJaxObject_2['startup'];
    typeset(arg: unknown[]): void;
    typesetPromise(arg: unknown[]): Promise<void>;
}

export declare interface RendererConfig<TEngine extends MathEngine> {
    engine: MathEngine;
    entryScript: string;
    document: Document;
    isEnabled: boolean;
    onRendered?: (mathjax: TEngine extends MathEngine.MathJax2 ? typeof MathJax : TEngine extends MathEngine.MathJax3 ? MathJaxObject : RenderMathInElementOptions) => void | Promise<void>;
    tapMathJaxConfig?: <TConfig = TEngine extends MathEngine.MathJax2 ? MathJax.Config : TEngine extends MathEngine.MathJax3 ? MathJaxObject : RenderMathInElementOptions>(config: TConfig) => TConfig;
}

export { }
